GDA Toolbox (public version) — GDA Toolbox v1.0 Manual

# GDA Toolbox (public version)

Public Repository at https://github.com/geomdata/gda-public/

Documentation at https://geomdata.github.io/gda-public/

This package provides easy-to-use tools for manipulating time-series signals (see the `timeseries.Signal` class), point clouds (see the `multidim.PointCloud` class) and simplicial complexes (see the `multidim.SimplicialComplex` class). The goal is to provide intuitive interfaces and fast, practical, and mathematically-correct methods for topological data analysis.

## Basic Use Cases

The repository contains many examples at http://nbviewer.jupyter.org/github/geomdata/gda-public/tree/master/examples

To dive into the tools, here are a few good examples to get started:

> - Multi-dimensional Data
>     - Using the `multidim.PointCloud` class to compute persistence diagrams of multidimensional data. See example-pointcloud
>     - Using the `multidim.covertree.CoverTree` class to compute Cover Trees with the Friends algorithm. See example-covertree
>     - Using the `multidim.models.CDER` class for supervised machine learning using the CDER algorithm. See example-cder
> - Time-Series Data
>     - Using the `timeseries.Signal` class to compute persistence of time-series data. See example-signal-pers0
>     - Using the `timeseries.SpaceCurve` class to build and study the geometry of trajectories. See example-trajectories
>     - Using the `timeseries.SpaceCurve` class to compute signature curves. See example-sigcurves
>     - Using mollifiers to clean up time-series data with gaps or jumps. See example-mollification

## Startup

- README for GDA-Public
  - Quick Start
  - Building Documentation
  - Running and Using
- Example Worksheets
- README for Advanced Installations
  - Online Setup and Testing with Anaconda on Linux/Mac
  - Online Setup and Testing with Anaconda on Windows
  - Offline Setup and Testing with Anaconda
  - Installation
  - Porting Changes
- Development Guidelines
  - Repository usage
  - Profiling
  - Style
  - Documentation
  - Testing
  - Docker Build Environment
- COPYRIGHT NOTICE
  - Authors
  - License

## General Framework

> - Multidimensional Data
> - Time-Series Data
> - Topological Constructions

# Fast Algorithms

Performance-sensitive algorithms are written in [Cython]. Usually, only core developers need to access these methods directly, as most users will use the pure Python interfaces for convenience and clarity.

`multidim.fast_algorithms` | This Cython module contains core algorithms for multidimensional data.
`timeseries.fast_algorithms` | This Cython module contains core algorithms for `timeseries.Signal` data.
`timeseries.curve_geometry` | This Cython module contains the core algorithms for the geometry of curves.
`homology.dim0` | This Cython module contains the core algorithms for 0-dimension topological algorithms.
`homology.dim1` | This Cython module contains the core algorithms for 1-dimensional topological algorithms.

# Indices and tables

- Index
- Module Index

- All Modules, Classes, and Methods

# References

### Table of Contents

- GDA Toolbox (public version)
  - Basic Use Cases
  - Startup
  - General Framework
- Fast Algorithms
- Indices and tables
- References

#### Next topic

README for GDA-Public